from distutils.core import setup

setup(
	name		= 'printnest',
	version		= '1.0.0',
	py_modules	= ['printnest'],
	author		= 'chengm1',
	author_email	= 'muhuan.cheng@hotmail.com',
	url		= 'http://github.com',
	discription	= 'A simple printer of nested lists',
)

